summaryrefslogtreecommitdiffstats
path: root/urpm.pm
diff options
context:
space:
mode:
authorPablo Saratxaga <pablo@mandriva.com>2003-07-18 13:46:17 +0000
committerPablo Saratxaga <pablo@mandriva.com>2003-07-18 13:46:17 +0000
commitc7acca059825ff9e0473af0b04e30dcce04af242 (patch)
tree1446755869372cf1f91b1148397cd48a82b2e19e /urpm.pm
parentd321502b43970e9568c80665f81d929b598f3173 (diff)
downloadurpmi-c7acca059825ff9e0473af0b04e30dcce04af242.tar
urpmi-c7acca059825ff9e0473af0b04e30dcce04af242.tar.gz
urpmi-c7acca059825ff9e0473af0b04e30dcce04af242.tar.bz2
urpmi-c7acca059825ff9e0473af0b04e30dcce04af242.tar.xz
urpmi-c7acca059825ff9e0473af0b04e30dcce04af242.zip
Corrected English typo
Diffstat (limited to 'urpm.pm')
-rw-r--r--urpm.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/urpm.pm b/urpm.pm
index 435cdfb0..3aca28ee 100644
--- a/urpm.pm
+++ b/urpm.pm
@@ -1663,7 +1663,7 @@ sub update_media {
}
} else {
#- read first pass hdlist or synthesis, try to open as synthesis, if file
#- is larger than 1MB, this is problably an hdlist else a synthesis.
#- anyway, if one tries fails, try another mode.
$options{callback} && $options{callback}('parse', $medium->{name});
my @unresolved_before = grep { ! defined $urpm->{provides}{$_} } keys %{$urpm->{provides} || {}};
@@ -2422,7 +2422,7 @@ sub get_source_packages {
}
$list_warning && $medium->{list} && -r "$urpm->{statedir}/$medium->{list}" and
$urpm->{error}(N("medium \"%s\" uses an invalid list file:
- mirror is problably not up-to-date, trying to use alternate method", $medium->{name}));
+ mirror is probably not up-to-date, trying to use alternate method", $medium->{name}));
} elsif (!%list_examined) {
$error = 1;
$urpm->{error}(N("medium \"%s\" does not define any location for rpm files", $medium->{name}));
@@ -1663,7 +1663,7 @@ sub update_media {
} else {
#- read first pass hdlist or synthesis, try to open as synthesis, if file
- #- is larger than 1MB, this is problably an hdlist else a synthesis.
+ #- is larger than 1MB, this is probably an hdlist else a synthesis.
#- anyway, if one tries fails, try another mode.
$options{callback} && $options{callback}('parse', $medium->{name});